window.Gleam.initSearch([{"doc":"gserde","title":"gserde","content":"# gserde\n\n**warning**: alpha quality package with poor code hygiene, including assert/panic/todo\nstatements.\n\n[![Package Version](https://img.shields.io/hexpm/v/gserde)](https://hex.pm/packages/gserde)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gserde/)\n\n```sh\ngleam add gserde\n```\n\n## usage\n\n1. Create custom type with a singular variant constructor. See the example\n   `src/foo.gleam` below.\n2. Run `gleam run -m gserde`.\n3. Observe the generated file `src/foo_json.gleam`.\n4. Use the new `foo_json` module!\n\n```gleam\n// src/foo.gleam\nimport gleam/option.{type Option}\npub type FooJson {\n  Foo(\n    a_bool: Bool,\n    b_int: Int,\n    c_float: Float,\n    d_two_tuple: #(Int, String),\n    e_option_int: Option(Int),\n    f_string_list: List(String),\n  )\n}\n\n// src/foo_json.gleam\n// generated!\nimport gleam/json\nimport gleam/dynamic\nimport internal/foo\n\npub fn to_json(t: foo.FooJson) {\n  json.object([\n    #(&quot;a_bool&quot;, json.bool(t.a_bool)),\n    #(&quot;b_int&quot;, json.int(t.b_int)),\n    #(&quot;c_float&quot;, json.float(t.c_float)),\n    #(\n      &quot;d_two_tuple&quot;,\n      json.preprocessed_array([\n        json.int(t.d_two_tuple.0),\n        json.string(t.d_two_tuple.1),\n      ]),\n    ),\n    #(&quot;e_option_int&quot;, json.nullable(t.e_option_int, json.int)),\n    #(&quot;f_string_list&quot;, json.array(t.f_string_list, json.string)),\n  ])\n}\n\npub fn to_string(t: foo.FooJson) {\n  json.to_string(to_json(t))\n}\n\npub fn get_decoder_foo() {\n  dynamic.decode6(\n    foo.Foo,\n    dynamic.field(&quot;a_bool&quot;, dynamic.bool),\n    dynamic.field(&quot;b_int&quot;, dynamic.int),\n    dynamic.field(&quot;c_float&quot;, dynamic.float),\n    dynamic.field(&quot;d_two_tuple&quot;, dynamic.tuple2(dynamic.int, dynamic.string)),\n    dynamic.field(&quot;e_option_int&quot;, dynamic.optional(dynamic.int)),\n    dynamic.field(&quot;f_string_list&quot;, dynamic.list(dynamic.string)),\n  )\n}\n\npub fn from_string(json_str: String) {\n  json.decode(json_str, get_decoder_foo())\n}\n\n// src/my_module.gleam\nimport foo\nimport foo_json\n\npub fn serialization_identity_test() {\n  let foo_1 = foo.Foo(..) // make a Foo\n\n  let foo_2 = foo_1\n    |&gt; foo_json.to_string // 👀, stringify the Foo to JSON!\n    |&gt; foo_json.from_string // 👀, parse the Foo from JSON!\n\n  foo_1 == foo_2 // pass the identity test\n}\n```\n\nYou can set `DEBUG=1` to get verbose output during codegen.\n\n## todo\n\n- [ ] complete all cases\n- [ ] remove all invocations of assert/panic/todo\n- [x] support non-gleam primitive types\n- [ ] handle all module references properly\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gserde&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"evil","title":"at","content":"pub fn at(l: List(a), index: Int) -&gt; Result(a, Nil)\n\nSynonyms:\nevil.at\nevil at","url":"evil.html#at"},{"doc":"evil","title":"expect","content":"pub fn expect(x: Result(a, b), msg: String) -&gt; a\n\nSynonyms:\nevil.expect\nevil expect","url":"evil.html#expect"},{"doc":"evil","title":"evil","content":"","url":"evil.html"},{"doc":"request","title":"Request","content":"pub type Request {\n  Request(\n    src_module_name: String,\n    type_name: String,\n    module: glance.Module,\n    variant: glance.Variant,\n    ser: Bool,\n    de: Bool,\n  )\n}\n\nRequest(\n  src_module_name: String,\n  type_name: String,\n  module: glance.Module,\n  variant: glance.Variant,\n  ser: Bool,\n  de: Bool,\n)\n\n\nSynonyms:\nrequest.Request\nrequest Request","url":"request.html#Request"},{"doc":"request","title":"request","content":"","url":"request.html"},{"doc":"ast","title":"get_import_path_from_mod_name","content":"pub fn get_import_path_from_mod_name(\n  module_str: String,\n  req: Request,\n) -&gt; String\n\nSynonyms:\nast.get_import_path_from_mod_name\nast get_import_path_from_mod_name","url":"ast.html#get_import_path_from_mod_name"},{"doc":"ast","title":"ast","content":"","url":"ast.html"},{"doc":"common","title":"decoder_name_of_t","content":"pub fn decoder_name_of_t(raw_name: String) -&gt; String\n\nSynonyms:\ncommon.decoder_name_of_t\ncommon decoder_name_of_t","url":"common.html#decoder_name_of_t"},{"doc":"common","title":"common","content":"","url":"common.html"},{"doc":"gserde","title":"gen","content":"pub fn gen(req: Request) -&gt; #(Request, String)\n\nSynonyms:\ngserde.gen\ngserde gen","url":"gserde.html#gen"},{"doc":"gserde","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngserde.main\ngserde main","url":"gserde.html#main"},{"doc":"gserde","title":"process_single","content":"pub fn process_single(\n  src_filename: String,\n  is_debug: Bool,\n) -&gt; Nil\n\nSynonyms:\ngserde.process_single\ngserde process_single","url":"gserde.html#process_single"},{"doc":"gserde","title":"gserde","content":"","url":"gserde.html"}]);